
# Boost 2 click

BOOST 2 click is a DC-DC step-up (boost) regulator that has a fixed 5V output, which can be obtained from any low voltage input - such as NiCd, NiMH or one cell Li-Po/Li-Ion batteries.

<p align="center">
  <img src="http://download.mikroe.com/images/click_for_ide/boost2_click.png" height=300px>
</p>

[click Product page](<https://www.mikroe.com/boost-2-click>)

---


#### Click library 

- **Author**        : MikroE Team
- **Date**          : jan 2020.
- **Type**          : GPIO type


# Software Support

We provide a library for the Boost2 Click 
as well as a demo application (example), developed using MikroElektronika 
[compilers](http://shop.mikroe.com/compilers). 
The demo can run on all the main MikroElektronika [development boards](http://shop.mikroe.com/development-boards).

Package can be downloaded/installed directly form compilers IDE(recommended way), or downloaded from our LibStock, or found on mikroE github account. 

## Library Description

> This library contains API for Boost2 Click driver.

#### Standard key functions :

- Config Object Initialization function.
> void boost2_cfg_setup ( boost2_cfg_t *cfg ); 
 
- Initialization function.
> BOOST2_RETVAL boost2_init ( boost2_t *ctx, boost2_cfg_t *cfg );

#### Example key functions :

- Set enable pin.
> void boost2_set_en_pin ( boost2_t *ctx, uint8_t new_state );
 
- Get PG pin state.
> uint8_t boost2_get_pg_pin ( boost2_t *ctx );

## Examples Description

> This application features very high efficiency, low noise and anti-ringing voltage output.

**The demo application is composed of two sections :**

### Application Init 

> Initializes click driver.

```c

void application_init ( void )
{
    log_cfg_t log_cfg;
    boost2_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info(&logger, "---- Application Init ----");

    //  Click initialization.

    boost2_cfg_setup( &cfg );
    BOOST2_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    boost2_init( &boost2, &cfg );
}
  
```

### Application Task

> Demonstrates the use of the click drivers function. It
shows how to enable or disable click operation, and how to check if supplied
voltage is good.

```c

void application_task ( void )
{
    log_printf( &logger, "Enabling click operation... \r\n" );
    boost2_set_en_pin( &boost2, 1 );
    Delay_ms(3000);
    
    log_printf( &logger, "Checking output voltage... \r\n" );
    Delay_ms(500);
    if ( boost2_get_pg_pin( &boost2 ))
    {
        log_printf( &logger, "Output voltage good. \r\n" );
    }
    else
    {
        log_printf( &logger, "Output voltage incorrect. \r\n" );
    }
    Delay_ms(3000);
    
    log_printf( &logger, "Disabling click operation... \r\n" );
    boost2_set_en_pin( &boost2, 0 );
    Delay_ms(5000); 
}  

```

The full application code, and ready to use projects can be  installed directly form compilers IDE(recommneded) or found on LibStock page or mikroE GitHub accaunt.

**Other mikroE Libraries used in the example:** 

- MikroSDK.Board
- MikroSDK.Log
- Click.Boost2

**Additional notes and informations**

Depending on the development board you are using, you may need 
[USB UART click](http://shop.mikroe.com/usb-uart-click), 
[USB UART 2 Click](http://shop.mikroe.com/usb-uart-2-click) or 
[RS232 Click](http://shop.mikroe.com/rs232-click) to connect to your PC, for 
development systems with no UART to USB interface available on the board. The 
terminal available in all Mikroelektronika 
[compilers](http://shop.mikroe.com/compilers), or any other terminal application 
of your choice, can be used to read the message.



---
